#!/bin/bash

# *****************************************************
# PROGRAM:	gxlat
# PURPOSE:	desktop gui for google translate
# AUTHOR:		vovchik (Puppy Linux forum)
# DEPENDS:	bash, gtkdialog, wget, ping, gxmessage
# PLATFORM:	Puppy Linux (actually, any *nix with GTK)
# DATE:		17-06-2010
# LICENCE:	GPL
# *****************************************************

# <text width-chars="1"><label>" "</label></text>

# *********************
# FUNCTIONS
# *********************

# thanks to shinobar
#  evaluating the function eval_gettext because of backwards compatibility
#+ normal use of eval_gettext requires ". gettext.sh"
#+ more info at http://www.gnu.org/s/hello/manual/gettext/Preparing-Shell-Scripts.html
eval_gettext () {
  local myMESSAGE=$(gettext "$1")
  eval echo \"$myMESSAGE\"
}


# -------------
function init_vars()
# -------------
{
     
	#VERSION="0.1b"
	VERSION="0.1c"
	file_base="$PWD"
	
    export TEXTDOMAIN=gxlat
    #export TEXTDOMAINDIR=/usr/share/locale
    # deviating from standard now:
    export TEXTDOMAINDIR="${file_base}/locale"
    export OUTPUT_CHARSET=UTF-8
    # some variables (labels or buttons which are used more than once)
    export T_from="$(gettext 'From')"
    export T_to="$(gettext 'To')"
    export T_translate="$(gettext 'Translate')"
    export T_close="$(gettext 'Close')"
	
	LOGOFILE="$file_base/img/translate-logo.png"
	file_lang="$file_base/dat/lang-list.txt"
	file_last_to="$file_base/dat/last_to.txt"
	file_last_from="$file_base/dat/last_from.txt"
	mylist=`cat "$file_lang"`
	if [ -e $file_last_to ]; then
		mylast_to="<item>"`cat "$file_last_to"`"</item>""$mylist"
	else
		mylist=`cat "$file_lang"`
	fi
	if [ -e $file_last_from ]; then
		mylast_from="<item>"`cat "$file_last_from"`"</item>""$mylist"
	else
		mylist=`cat "$file_lang"`
	fi
	echo " " > ./tmp/to_text.txt
}


# -------------
function swap_langs()
# -------------
{
 	tmp1="$mylast_from"
 	mylast_from="$mylast_to"
 	mylast_to="$tmp1"
 	TO="$mylast_to"
 	FROM="$mylast_from"
 	export mylast_to
 	export mylast_from
}

# --------------
function swap_text()
# --------------
{
	tmp=$TO_TEXT
	TO_TEXT="$FROM_TEXT"
	FROM_TEXT="$TO_TEXT"
	tmp=""
	export TO_TEXT
	export FROM_TEXT
}

# --------------
function strip_lang_name()
# --------------
{
	long_from="$FROM"
	long_to="$TO"
	export long_from
	export long_to
	strip_start="${FROM#*[}"
	strip_end="${strip_start%]*}"
	myFROM=$strip_end
	strip_start="${TO#*[}"
	strip_end="${strip_start%]*}"
	myTO=$strip_end
}

# -------------
function translate()
# -------------
{	
 
	strip_lang_name
	if [ $myTO == $myFROM ] ; then
		printf "$(gettext 'Bad language choice. '%1s' and '%2s' cannot be the same.')" $T_from $T_to
		printf "$(gettext 'Bad language choice. '%1s' and '%2s' cannot be the same.')" $T_from $T_to > ./tmp/to_text.txt
	else
		#echo "From: $FROM_TEXT"
		echo "${T_from}: $FROM_TEXT"
		FROM_TEXT=$(sed -r '
		s/&/&amp;/
		s/"/&quot;/
		s/</&lt;/
		s/>/&gt;/
		' <<< $FROM_TEXT) 
		TO_TEXT=`wget -qO- "http://ajax.googleapis.com/ajax/services/language/translate?v=1.0&q=$FROM_TEXT&langpair=$myFROM|${myTO:-en}" | sed 's/.*"translatedText":"\([^"]*\)".*}/\1\n/' `
		#echo "To:   $TO_TEXT"
		echo "${T_to}:   $TO_TEXT"
		TO_TEXT=`echo "$TO_TEXT" | ./bin/html-clean`
		echo "$TO_TEXT" > ./tmp/to_text.txt
		export TO_TEXT
	fi
}

# --------------
function make_gui()
# --------------
{
export MAIN='
	<window window_position="1" title="Google Translate - v.'$VERSION'" icon-name="gtk-network">
		<vbox>
			<frame>
				<pixmap><input file>'$LOGOFILE'</input></pixmap>
			</frame>
			<frame '`gettext "Source text:"`' >
				<edit editable="true"  wrap-mode="2">
					<variable>FROM_TEXT</variable>
					<default>'`gettext "Sample text"`'</default>
					<height>100</height>
					<width>560</width>
				</edit>
			</frame>
			<frame '`gettext "Languages:"`' >
			<vbox>
				<hbox>
					<text width-chars="5">
						<label>'"${T_from}:"'</label>
					</text>
					<combobox allow-empty="true" case-sensitive="true" value-in-list="true">
						<variable>FROM</variable>
							'$mylast_from'
					</combobox>
					<text width-chars="5">
						<label>'"${T_to}:"'</label>
					</text>
					<combobox allow-empty="true" case-sensitive="true" value-in-list="true">
						<variable>TO</variable>
							'$mylast_to'
					</combobox>
					<text width-chars="3">
						<label>"  "</label>
					</text>
					<button>
						<label>'`gettext "Clear"`'</label>
						<input file stock="gtk-clear"></input>
						<action>clear:FROM_TEXT</action>
						<action>clear:TO_TEXT</action>
					</button>
					<button>
						<label>'`gettext "Swap"`'</label>
						<input file stock="gtk-refresh"></input>
						<action>swap_langs</action>
						<action>insert:$mylast_from, FROM</action>
						<action>insert:$mylast_to, TO</action>
						<action>refresh:TO</action>
						<action>refresh:FROM</action>
						<action type="refresh">TO</action>
						<action type="refresh">FROM</action>
					</button>
					<button>
						<label>'"$T_translate"'</label>
						<input file stock="gtk-network"></input>
						<action>translate $FROM_TEXT $FROM $TO</action>
						<action>refresh:TO_TEXT</action>
						<action type="refresh">TO_TEXT</action>
					</button>
				</hbox>
			</vbox>
			</frame>
			<frame '`gettext "Translated text:"`' >
				<edit editable="false" wrap-mode="2">
					<variable>TO_TEXT</variable>
					<input file>'$file_base'/tmp/to_text.txt</input> 
					<action>refresh:TO_TEXT</action>
					<height>100</height>
					<width>560</width>
				</edit>
			</frame>
			<hbox>
				<button width-request="90">
					<label>'`gettext "Help"`'</label>
					<input file stock="gtk-help"></input>
					<action type="launch">show_xlat_help</action>
				</button>
				<button width-request="90">
					<label>'"$T_close"'</label>
					<input file stock="gtk-cancel"></input>
					<action>echo $FROM > dat/last_from.txt</action>
					<action>echo $TO > dat/last_to.txt</action>
					<action type="exit">EXIT_NOW</action>
				</button>
			</hbox>
		</vbox>
		<action signal="hide">exit:Exit</action> 
	</window>'
}

# -------------
function make_help_gui()
# -------------
{
	# this is the help text
	myxlathelp0="`gettext \"<b>Gxlat</b> is intended to enable access to the Google translate facility from the desktop without the need to load a javascript-enabled browser. You will need a live Internet connection.\"`" 
    myxlathelp1="`gettext \"1. Select a text to translate (<i>typed in or pasted</i>).\"`" 
    myxlathelp2="`eval_gettext \"2. Select the <b>\\\${T_from}</b> language via the leftmost combo box.\"`" 

    myxlathelp3="`eval_gettext \"3. Select the target language via the <b>\\\${T_to}</b> combo box.\"`" 

    myxlathelp4="`eval_gettext \"4. Click on the <b>\\\${T_translate}</b> button.\"`" 
    myxlathelp5="`gettext \"5. The Google translation will appear in the bottom window.\"`" 
    myxlathelp6="`eval_gettext \"6. Click the <b>\\\${T_close}</b> button to exit the application. \"`" 

	myxlathelp="$myxlathelp0 

 $myxlathelp1 
 $myxlathelp2 
 $myxlathelp3 
 $myxlathelp4 
 $myxlathelp5 
 $myxlathelp6 

         Vovchik, Puppy Linux Forum, June 2010
                       www.murga-linux.com/puppy"
    #  above code might be simpler but this is how I have made it work 
    #+ the variable has to preceeded by triple-backslash e.g. \\\${T_from}
    #+ this variable is used in main window AND in help
    #+ If a translator decides to change the translation this has to be done just once !
    	
	show_xlat_help='
	<window title="Google Translate Help" icon-name="gtk-about">
		<vbox>
			<frame>
				<pixmap><input file>'$LOGOFILE'</input></pixmap>
			</frame>
			<frame>
				<text use-markup="true" wrap="true">
					<label>"'$myxlathelp'"</label>
				</text>
			</frame>
			<hbox>
				<button width-request="90">
					<input file icon="gtk-info"></input>
					<label>ReadMe </label>
					<action>launch:show_readme</action>
				</button>
				<button width-request="90">
					<input file stock="gtk-cancel"></input>
					<label>Close</label>
					<action>closewindow:show_shout_help</action>
				</button>
			</hbox>
		</vbox>
	</window>
	'
	export show_xlat_help
}

# -------------
make_readme_gui()
# -------------
{
show_readme='
	<window title="Google Translate Readme" icon-name="gtk-info">
		<vbox>
			<frame>
				<pixmap><input file>'$LOGOFILE'</input></pixmap>
			</frame>
			<frame Readme text>
				<edit editable="false">
					<input file>'$file_base/doc/readme.txt'</input>
					<width>600</width><height>350</height>
				</edit>
			</frame>
			<hbox>
				<button width-request="90">
					<input file stock="gtk-cancel"></input>
					<label>Close </label>
					<action>closewindow:show_readme</action>
				</button>
			</hbox>
		</vbox>
	</window>'

	export show_readme
}

# *********************
# END FUNCTIONS
# *********************


# *********************
# MAIN
# *********************

init_vars
#check_inet
# replacement for check_inet part 1 L18L
yaf-splash -placement center -bg yellow -fontsize large -text "`gettext \"Please wait, probing primary remote site...\"`" &
YPID=$!
for n in 3 2 1 0
do
 myDUMMY_TEXT=`wget -qO- "http://ajax.googleapis.com/ajax/services/language/translate?v=1.0&q=dummy&langpair=en|de" | sed 's/.*"translatedText":"\([^"]*\)".*}/\1\n/' `
 [ "$myDUMMY_TEXT" != "" ] && break
 sleep `echo $n`
 #echo -n $n
done
# end replacement for check_inet part 1 L18L

make_help_gui
make_readme_gui
make_gui
export -f swap_langs
export -f strip_lang_name
export -f translate
#gtkdialog3 -p MAIN
# replacement for check_inet part 2 L18L
if [ "$myDUMMY_TEXT" != "" ] 
then
 kill $YPID
 gtkdialog3 -p MAIN
else
 T_noco=$(gettext "No need to wait anymore, no connection to remote site...")
 echo "$T_noco"
 yaf-splash -placement center -bg yellow -fontsize large -text "$T_noco"
fi 
# end replacement for check_inet part 2 L18L

# *********************
# END MAIN
# *********************
